Buttons - Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

## Buttons

### Standard Buttons

Normal
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark
Active state
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark
Disabled
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark

### Outline Buttons

Use `.btn-outline-*` class for outline buttons.

Normal
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark
Active state
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark
Disabled
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark

### Ghost Buttons

Use `.btn-ghost-*` class for ghost buttons.

Normal
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark
Active state
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark
Disabled
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark

### Square Buttons

Use `.btn-square` class for square buttons.

Normal
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark

### Pill Buttons

Use `.btn-pill` class for pill buttons.

Normal
Primary
Secondary
Success
Warning
Danger
Info
Light
Dark

### Extra colors

Blue
Azure
Indigo
Purple
Pink
Red
Orange
Yellow
Lime
Green
Teal
Cyan

### Icon buttons

### Social colors

Facebook
Twitter
Google
Youtube
Vimeo
Dribbble
Github
Instagram
Pinterest
VK
RSS
Flickr
Bitbucket
Tabler